@@ -8,7 +8,6 @@ Documentation DOCSTRING follows numpy-style wherever possible.
 See https://numpydoc.readthedocs.io/en/latest/format.html
 
 .. todo::
-    - Add new rig class for structured light (projector + camera).
     - Add new rig class for uncalibrated stereo.
 """
 import json
@@ -317,8 +316,8 @@ class RectifiedStereoRig(StereoRig):
         self.rectHomography1 = rectHomography1  # Rectification homographies
         self.rectHomography2 = rectHomography2
         
-        # Final intrinsic matrices that keep track of all affine transformations applied, are
-        # calculated in self.computeRectificationMaps() considering destination dimensions and zoom.
+        # Matrices that keep track of all affine transformations applied to left and right cameras.
+        # These calculated in self.computeRectificationMaps() considering destination dimensions and zoom.
         # N.B. These will be needed for depth reconstruction!
         self.K1 = None
         self.K2 = None
@@ -407,7 +406,7 @@ class RectifiedStereoRig(StereoRig):
         
         New projection matrices, after rectification, share the same orientation `Rcommon`,
         have only one horizontal displacement (the baseline) and
-        have new intrinsics (`K1` and `K2`) that depends on all the rigid manipulation done after rectification.
+        have new intrinsics that depends on all the rigid manipulation done after rectification.
         
         Returns
         -------
@@ -422,7 +421,7 @@ class RectifiedStereoRig(StereoRig):
         return P1, P2  
     
     
-    def computeRectificationMaps(self, destDims=None, zoom=1):
+    def computeRectificationMaps(self, destDims=None, alpha=1):
         """
         Compute the two maps to undistort and rectify the stereo pair.
         
@@ -435,8 +434,11 @@ class RectifiedStereoRig(StereoRig):
         ----------
         destDims: tuple, optional
             Resolution of destination images as (width, height) tuple (default to first image resolution).
-        zoom: float, optional
-            Zoom on the final images. Default to 1.
+        alpha : float, optional
+            Scaling parameter between 0 and 1 to be applied to both images. If alpha=1 (default), the corners of the original
+            images are preserved. If alpha=0, only valid rectangle is made visible.
+            Intermediate values produce a result in the middle. Extremely skewed camera positions
+            do not work well with alpha<1.
         
         Returns
         -------
@@ -456,10 +458,10 @@ class RectifiedStereoRig(StereoRig):
         
         # Find fitting matrices, as additional correction of the new camera matrices (if any).
         # Useful e.g. to change destination image resolution or zoom.
-        Fit = rectification.getFittingMatrix(self.intrinsic1, self.intrinsic2, self.rectHomography1, self.rectHomography2, self.res1, self.res2, self.distCoeffs1, self.distCoeffs2, destDims, zoom)
+        Fit = rectification.getFittingMatrix(self.intrinsic1, self.intrinsic2, self.rectHomography1, self.rectHomography2, self.res1, self.res2, self.distCoeffs1, self.distCoeffs2, destDims, alpha)
         
-        # Isolate affine transformation applied after rectification
-        # These would be the FINAL new camera intrinsics (needed for 3D reconstrunction)
+        # Group all the transformations applied after rectification
+        # These would be needed for 3D reconstrunction
         self.K1 = Fit.dot(self.rectHomography1).dot(self.intrinsic1).dot(self.Rcommon.T)
         self.K2 = Fit.dot(self.rectHomography2).dot(self.intrinsic2.dot(self.R)).dot(self.Rcommon.T)
         
@@ -468,7 +470,6 @@ class RectifiedStereoRig(StereoRig):
         R2 = self.Rcommon.dot(self.R.T)
         
         # Recompute final maps considering fitting transformations too
-        #P1, P2 = self.getRectifiedProjectionMatrices()
         self.mapx1, self.mapy1 = cv2.initUndistortRectifyMap(self.intrinsic1, self.distCoeffs1, R1, self.K1, destDims, cv2.CV_32FC1)
         self.mapx2, self.mapy2 = cv2.initUndistortRectifyMap(self.intrinsic2, self.distCoeffs2, R2, self.K2, destDims, cv2.CV_32FC1)
         
